Zope.org

You are not logged in Log in Join
You are here: Home

Download Download Zope Zope Products Zope CMF Resources Report Bugs Mailing Lists User Groups License Documentation The Zope Book API reference ZPT reference Developer Guide CMF Documentation Zope Articles Zope How-Tos Books In Print About Zope What Is Zope? Zope Powered Sites About Zope.org Member FAQ Business Zope Corporation Solution Providers Zope Training Developers Zope Projects Zope 3 Zope CVS Zope SVN Zope Sites ##### Log in Name Password Forgot your password? New user? |
# Welcome to Zope.org The Web Site for the Zope Community Zope is an open source application server for building content management systems, intranets, portals, and custom applications. The Zope community consists of hundreds of companies and thousands of developers all over the world, working on building the platform and Zope applications. Zope is written in Python, a highly-productive, object-oriented scripting language. more ## Zope for...
New Users Introduction To Zope, About Python Web Masters Using Apache, Security, ZPT, DTML | Product Developers Developers Guide, Unit Testing Zope Developers Content Management Framework (CMF), Products, Using CVS/SVN, Bug Days
## What You can do on Zope.org Membership gives you your own home folder on Zope.org where you can create and manage your own Zope objects. The objects you create and maintain will be available to all people who visit Zope.org. Site visitors can find your content using the site search or by browsing your member folder. Many pages on the zope.org site are generated by search queries - by providing metadata such as keywords with your content it can appear in automated site pages such as product or news listings. more ## Zope Training ... Send your Zope training announcements to webmaster@zope.org ## Plone Training ... Send your Plone training announcements to webmaster@zope.org | ##### Planets Planet Zope Zope related news Planet Plone Plone related news ##### News ZopeDictDB 0.1 October 30 Russian Zope3 Maillist October 26 kiss 0.1: Serve filesystem content, simply October 17 ZInformixDA 0.3 released October 16 zForum 1.0 Release 16 - Skin Me October 16 ##### Products ContentDispatcher: Dispatch content over many plone sites in one click ! (1.0.1) October 11 Content Management Framework (2.1.0-alpha) October 09 (0.1) October 08 Zope (2_10_0-final) October 03 Zope 3 (3.2.2) October 02